@@ -8,10 +8,10 @@ import pandas as pd
 from pathlib import Path  
 from threading import Thread
 
-from seEvo_evolution_loop_1D import seEvo1Dnorm
-from seEvo_analytical_model_1D import seEvo1Danalytical
-# from seEvo1D.seEvo_evolution_loop_1D import seEvo1Dnorm
-# from seEvo1D.seEvo_analytical_model_1D import seEvo1Danalytical
+# from seEvo_evolution_loop_1D import seEvo1Dnorm
+# from seEvo_analytical_model_1D import seEvo1Danalytical
+from seEvo1D.seEvo_evolution_loop_1D import seEvo1Dnorm
+from seEvo1D.seEvo_analytical_model_1D import seEvo1Danalytical
 
 end = False
 
@@ -78,10 +78,11 @@ def seEvoInit(iPop,
         if iter_outer <= simTime:
             begin = 0
             t = time.time() - t  
-            if select == 0:
-                q.put(['0', str(ID), str(iter_outer)])
-            elif select == 1 and iter_outer % 10 == 0:
-                q.put(['0', str(ID), str(iter_outer)])
+            if q != None:
+                if select == 0:
+                    q.put(['0', str(ID), str(iter_outer)])
+                elif select == 1 and iter_outer % 10 == 0:
+                    q.put(['0', str(ID), str(iter_outer)])
             
             if iter_inner * skip <= simTime:
                 plotter(copy.deepcopy(iPop), file_name, file_localization, copy.copy(iter_inner * skip), plots, select)                
@@ -110,22 +111,23 @@ def seEvoInit(iPop,
             iter_outer = int(simTime) + 1
         
         if end:
-            q.put(['exit', str(ID) + ', analytical' * (select == 1) + ', normal' * (select == 0)])
+            if q != None:
+                q.put(['exit', str(ID) + ', analytical' * (select == 1) + ', normal' * (select == 0)])
             break
         
         if not select:
             if (int(simTime) - steps >= 0 or iPop._shape[1] >= 10**6) and break_type == 0:
-                print('all steps')
+                print(str(ID) + ': all steps')
                 end = True
             elif (iPop._shape[1] >= steps or iPop._shape[1] >= 10**6) and break_type == 1 and select != 2:
-                print('all cells')
+                print(str(ID) + ': all steps')
                 end = True
         else:
             if (int(simTime) - steps >= 0 or sum(iPop[1,:]) >= 10**6) and break_type == 0:
-                print('all steps')
+                print(str(ID) + ': all steps')
                 end = True
             elif (sum(iPop[1,:]) >= steps or sum(iPop[1,:]) >= 10**6) and break_type == 1 and select != 2:
-                print('all cells')
+                print(str(ID) + ': all steps')
                 end = True
         
         if select == 0:            
