@@ -32,8 +32,8 @@ def seEvo1Dnorm(iPop, cap, tau_x, A, mut_prob, mut_effect, simTime):
     # popSize = len(iPop[:,0])
     
     mdt = (popSize/cap)**A
-    tau = tau_x * cap/popSize
-    # tau = tau_x
+    # tau = tau_x * cap/popSize
+    tau = tau_x
     mdv = iPop[:,0].toarray()[:,0]
     # mdv = iPop[:,0]
     
